"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OpsgenieRegion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OpsgenieRegionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OpsgenieRegion.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OPSGENIE_REGION_INVALID: _OpsgenieRegion.ValueType  # 0
    OPSGENIE_REGION_US: _OpsgenieRegion.ValueType  # 1
    OPSGENIE_REGION_EU: _OpsgenieRegion.ValueType  # 2

class OpsgenieRegion(_OpsgenieRegion, metaclass=_OpsgenieRegionEnumTypeWrapper): ...

OPSGENIE_REGION_INVALID: OpsgenieRegion.ValueType  # 0
OPSGENIE_REGION_US: OpsgenieRegion.ValueType  # 1
OPSGENIE_REGION_EU: OpsgenieRegion.ValueType  # 2
global___OpsgenieRegion = OpsgenieRegion

class OpsgenieIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTED_OPSGENIE_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    OPSGENIE_SETTINGS_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    OPSGEINIE_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    @property
    def encrypted_opsgenie_auth_config(self) -> global___OpsgenieAuthConfig:
        """Encrypted Opsgenie auth configuration"""
    @property
    def opsgenie_settings(self) -> global___OpsgenieSettings:
        """All Opsgenie settings"""
    base_url: builtins.str
    """Opsgenie base url. Determined by the Region"""
    @property
    def opsgeinie_system_secret(self) -> global___OpsgeinieSystemSecretDescriptor:
        """Opsgenie system secret descriptor"""
    def __init__(
        self,
        *,
        encrypted_opsgenie_auth_config: global___OpsgenieAuthConfig | None = ...,
        opsgenie_settings: global___OpsgenieSettings | None = ...,
        base_url: builtins.str = ...,
        opsgeinie_system_secret: global___OpsgeinieSystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_opsgenie_auth_config", b"encrypted_opsgenie_auth_config", "opsgeinie_system_secret", b"opsgeinie_system_secret", "opsgenie_settings", b"opsgenie_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "base_url", b"base_url", "encrypted_opsgenie_auth_config", b"encrypted_opsgenie_auth_config", "opsgeinie_system_secret", b"opsgeinie_system_secret", "opsgenie_settings", b"opsgenie_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["opsgeinie_system_secret"] | None: ...

global___OpsgenieIntegration = OpsgenieIntegration

class OpsgenieIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPSGENIE_SETTINGS_FIELD_NUMBER: builtins.int
    OPSGENIE_AUTH_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def opsgenie_settings(self) -> global___OpsgenieSettings:
        """There used to be another field which was deprecated, hence, field numbers start from 2
        All Opsgenie settings
        """
    @property
    def opsgenie_auth_configuration(self) -> global___OpsgenieAuthConfig: ...
    def __init__(
        self,
        *,
        opsgenie_settings: global___OpsgenieSettings | None = ...,
        opsgenie_auth_configuration: global___OpsgenieAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "opsgenie_auth_configuration", b"opsgenie_auth_configuration", "opsgenie_settings", b"opsgenie_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "opsgenie_auth_configuration", b"opsgenie_auth_configuration", "opsgenie_settings", b"opsgenie_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["opsgenie_auth_configuration"] | None: ...

global___OpsgenieIntegrationSpec = OpsgenieIntegrationSpec

class OpsgenieSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_FIELD_NUMBER: builtins.int
    region: global___OpsgenieRegion.ValueType
    """Opsgenie region"""
    def __init__(
        self,
        *,
        region: global___OpsgenieRegion.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["region", b"region"]) -> None: ...

global___OpsgenieSettings = OpsgenieSettings

class OpsgenieAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    def __init__(
        self,
        *,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> None: ...

global___OpsgenieAuthConfig = OpsgenieAuthConfig

class OpsgeinieSystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    API_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """Opsgenie system secret name"""
    api_key_secret_key: builtins.str
    """Opsgenie system secret api_key secret key"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        api_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_secret_key", b"api_key_secret_key", "secret_name", b"secret_name"]) -> None: ...

global___OpsgeinieSystemSecretDescriptor = OpsgeinieSystemSecretDescriptor

class OpsgenieValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPSGENIE_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def opsgenie_auth_config(self) -> global___OpsgenieAuthConfig:
        """Opsgenie auth config"""
    region: global___OpsgenieRegion.ValueType
    """Opsgenie region"""
    def __init__(
        self,
        *,
        opsgenie_auth_config: global___OpsgenieAuthConfig | None = ...,
        region: global___OpsgenieRegion.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["opsgenie_auth_config", b"opsgenie_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["opsgenie_auth_config", b"opsgenie_auth_config", "region", b"region"]) -> None: ...

global___OpsgenieValidationSpec = OpsgenieValidationSpec

class OpsgenieIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OpsgenieIntegrationOptions = OpsgenieIntegrationOptions
