# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.builds import internal_builds_orchestrator_service_pb2 as qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2


class InternalBuildsOrchestratorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BuildModel = channel.unary_unary(
                '/qwak.builds.orchestrator.InternalBuildsOrchestratorService/BuildModel',
                request_serializer=qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelResponse.FromString,
                )


class InternalBuildsOrchestratorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BuildModel(self, request, context):
        """Build a serving model image
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalBuildsOrchestratorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BuildModel': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildModel,
                    request_deserializer=qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.builds.orchestrator.InternalBuildsOrchestratorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalBuildsOrchestratorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BuildModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.InternalBuildsOrchestratorService/BuildModel',
            qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelRequest.SerializeToString,
            qwak_dot_builds_dot_internal__builds__orchestrator__service__pb2.InternalBuildModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
