# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/collection/event/collection_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/vectors/v1/collection/event/collection_event.proto\x12%qwak.vector.store.v1.collection.event\x1a\x1fgoogle/protobuf/timestamp.proto\"t\n\x0f\x43ollectionEvent\x12\x15\n\rcollection_id\x18\x01 \x01(\t\x12\x34\n\x10last_modified_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cretry_number\x18\x03 \x01(\x05\x42L\n\'com.qwak.ai.vectors.v1.collection.eventP\x01Z\x1fqwak/vector_management/v1;eventb\x06proto3')



_COLLECTIONEVENT = DESCRIPTOR.message_types_by_name['CollectionEvent']
CollectionEvent = _reflection.GeneratedProtocolMessageType('CollectionEvent', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONEVENT,
  '__module__' : 'qwak.vectors.v1.collection.event.collection_event_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.v1.collection.event.CollectionEvent)
  })
_sym_db.RegisterMessage(CollectionEvent)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.vectors.v1.collection.eventP\001Z\037qwak/vector_management/v1;event'
  _COLLECTIONEVENT._serialized_start=131
  _COLLECTIONEVENT._serialized_end=247
# @@protoc_insertion_point(module_scope)
