# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/fitness_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2
from _qwak_proto.qwak.fitness_service import status_pb2 as qwak_dot_fitness__service_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/fitness_service/fitness_service.proto\x12\x14qwak.fitness.service\x1a\"qwak/fitness_service/fitness.proto\x1a!qwak/fitness_service/status.proto\"H\n\x11\x42uildModelRequest\x12\x33\n\nbuild_spec\x18\x01 \x01(\x0b\x32\x1f.qwak.fitness.service.BuildSpec\"\x14\n\x12\x42uildModelResponse\"+\n\x17\x43\x61ncelBuildModelRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelBuildModelResponse\"2\n\x1eGetRemoteBuildingStatusRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"]\n\x1fGetRemoteBuildingStatusResponse\x12:\n\x06status\x18\x01 \x01(\x0b\x32*.qwak.fitness.service.RemoteBuildingStatus\"4\n CleanRemoteBuildResourcesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"#\n!CleanRemoteBuildResourcesResponse2\xfc\x03\n\x0e\x46itnessService\x12_\n\nBuildModel\x12\'.qwak.fitness.service.BuildModelRequest\x1a(.qwak.fitness.service.BuildModelResponse\x12q\n\x10\x43\x61ncelBuildModel\x12-.qwak.fitness.service.CancelBuildModelRequest\x1a..qwak.fitness.service.CancelBuildModelResponse\x12\x86\x01\n\x17GetRemoteBuildingStatus\x12\x34.qwak.fitness.service.GetRemoteBuildingStatusRequest\x1a\x35.qwak.fitness.service.GetRemoteBuildingStatusResponse\x12\x8c\x01\n\x19\x43leanRemoteBuildResources\x12\x36.qwak.fitness.service.CleanRemoteBuildResourcesRequest\x1a\x37.qwak.fitness.service.CleanRemoteBuildResourcesResponseB#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')



_BUILDMODELREQUEST = DESCRIPTOR.message_types_by_name['BuildModelRequest']
_BUILDMODELRESPONSE = DESCRIPTOR.message_types_by_name['BuildModelResponse']
_CANCELBUILDMODELREQUEST = DESCRIPTOR.message_types_by_name['CancelBuildModelRequest']
_CANCELBUILDMODELRESPONSE = DESCRIPTOR.message_types_by_name['CancelBuildModelResponse']
_GETREMOTEBUILDINGSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetRemoteBuildingStatusRequest']
_GETREMOTEBUILDINGSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetRemoteBuildingStatusResponse']
_CLEANREMOTEBUILDRESOURCESREQUEST = DESCRIPTOR.message_types_by_name['CleanRemoteBuildResourcesRequest']
_CLEANREMOTEBUILDRESOURCESRESPONSE = DESCRIPTOR.message_types_by_name['CleanRemoteBuildResourcesResponse']
BuildModelRequest = _reflection.GeneratedProtocolMessageType('BuildModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELREQUEST,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildModelRequest)
  })
_sym_db.RegisterMessage(BuildModelRequest)

BuildModelResponse = _reflection.GeneratedProtocolMessageType('BuildModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELRESPONSE,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildModelResponse)
  })
_sym_db.RegisterMessage(BuildModelResponse)

CancelBuildModelRequest = _reflection.GeneratedProtocolMessageType('CancelBuildModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBUILDMODELREQUEST,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CancelBuildModelRequest)
  })
_sym_db.RegisterMessage(CancelBuildModelRequest)

CancelBuildModelResponse = _reflection.GeneratedProtocolMessageType('CancelBuildModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBUILDMODELRESPONSE,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CancelBuildModelResponse)
  })
_sym_db.RegisterMessage(CancelBuildModelResponse)

GetRemoteBuildingStatusRequest = _reflection.GeneratedProtocolMessageType('GetRemoteBuildingStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREMOTEBUILDINGSTATUSREQUEST,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.GetRemoteBuildingStatusRequest)
  })
_sym_db.RegisterMessage(GetRemoteBuildingStatusRequest)

GetRemoteBuildingStatusResponse = _reflection.GeneratedProtocolMessageType('GetRemoteBuildingStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREMOTEBUILDINGSTATUSRESPONSE,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.GetRemoteBuildingStatusResponse)
  })
_sym_db.RegisterMessage(GetRemoteBuildingStatusResponse)

CleanRemoteBuildResourcesRequest = _reflection.GeneratedProtocolMessageType('CleanRemoteBuildResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEANREMOTEBUILDRESOURCESREQUEST,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CleanRemoteBuildResourcesRequest)
  })
_sym_db.RegisterMessage(CleanRemoteBuildResourcesRequest)

CleanRemoteBuildResourcesResponse = _reflection.GeneratedProtocolMessageType('CleanRemoteBuildResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLEANREMOTEBUILDRESOURCESRESPONSE,
  '__module__' : 'qwak.fitness_service.fitness_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CleanRemoteBuildResourcesResponse)
  })
_sym_db.RegisterMessage(CleanRemoteBuildResourcesResponse)

_FITNESSSERVICE = DESCRIPTOR.services_by_name['FitnessService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _BUILDMODELREQUEST._serialized_start=139
  _BUILDMODELREQUEST._serialized_end=211
  _BUILDMODELRESPONSE._serialized_start=213
  _BUILDMODELRESPONSE._serialized_end=233
  _CANCELBUILDMODELREQUEST._serialized_start=235
  _CANCELBUILDMODELREQUEST._serialized_end=278
  _CANCELBUILDMODELRESPONSE._serialized_start=280
  _CANCELBUILDMODELRESPONSE._serialized_end=306
  _GETREMOTEBUILDINGSTATUSREQUEST._serialized_start=308
  _GETREMOTEBUILDINGSTATUSREQUEST._serialized_end=358
  _GETREMOTEBUILDINGSTATUSRESPONSE._serialized_start=360
  _GETREMOTEBUILDINGSTATUSRESPONSE._serialized_end=453
  _CLEANREMOTEBUILDRESOURCESREQUEST._serialized_start=455
  _CLEANREMOTEBUILDRESOURCESREQUEST._serialized_end=507
  _CLEANREMOTEBUILDRESOURCESRESPONSE._serialized_start=509
  _CLEANREMOTEBUILDRESOURCESRESPONSE._serialized_end=544
  _FITNESSSERVICE._serialized_start=547
  _FITNESSSERVICE._serialized_end=1055
# @@protoc_insertion_point(module_scope)
