"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.admiral.user_application_instance.v0.user_application_instance_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateUserApplicationInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def create_options(self) -> qwak.admiral.user_application_instance.v0.user_application_instance_pb2.CreateOptions:
        """Options for creation a user application instance"""
    def __init__(
        self,
        *,
        create_options: qwak.admiral.user_application_instance.v0.user_application_instance_pb2.CreateOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_options", b"create_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_options", b"create_options"]) -> None: ...

global___CreateUserApplicationInstanceRequest = CreateUserApplicationInstanceRequest

class CreateUserApplicationInstanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateUserApplicationInstanceResponse = CreateUserApplicationInstanceResponse

class UpdateUserApplicationInstanceSpecRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def update_options(self) -> qwak.admiral.user_application_instance.v0.user_application_instance_pb2.UpdateSpecOptions:
        """Options for updating a user application instance"""
    def __init__(
        self,
        *,
        update_options: qwak.admiral.user_application_instance.v0.user_application_instance_pb2.UpdateSpecOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["update_options", b"update_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["update_options", b"update_options"]) -> None: ...

global___UpdateUserApplicationInstanceSpecRequest = UpdateUserApplicationInstanceSpecRequest

class UpdateUserApplicationInstanceSpecResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateUserApplicationInstanceSpecResponse = UpdateUserApplicationInstanceSpecResponse

class GetUserApplicationInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Identifier:
        """The identifier of the user application instance to get"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Identifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___GetUserApplicationInstanceRequest = GetUserApplicationInstanceRequest

class GetUserApplicationInstanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Description:
        """Full details of a user application instance"""
    def __init__(
        self,
        *,
        description: qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Description | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___GetUserApplicationInstanceResponse = GetUserApplicationInstanceResponse

class DeleteUserApplicationInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Identifier:
        """The identifier of the user application instance to delete"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.user_application_instance.v0.user_application_instance_pb2.Identifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___DeleteUserApplicationInstanceRequest = DeleteUserApplicationInstanceRequest

class DeleteUserApplicationInstanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteUserApplicationInstanceResponse = DeleteUserApplicationInstanceResponse
