# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/personalization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/administration/account/v1/personalization.proto\x12\x1bqwak.administration.account\"K\n\x16\x41\x63\x63ountPersonalization\x12\x31\n\x05\x62rand\x18\x01 \x01(\x0b\x32\".qwak.administration.account.Brand\" \n\x05\x42rand\x12\x17\n\x0flogo_image_path\x18\x01 \x01(\tB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_ACCOUNTPERSONALIZATION = DESCRIPTOR.message_types_by_name['AccountPersonalization']
_BRAND = DESCRIPTOR.message_types_by_name['Brand']
AccountPersonalization = _reflection.GeneratedProtocolMessageType('AccountPersonalization', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPERSONALIZATION,
  '__module__' : 'qwak.administration.account.v1.personalization_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.AccountPersonalization)
  })
_sym_db.RegisterMessage(AccountPersonalization)

Brand = _reflection.GeneratedProtocolMessageType('Brand', (_message.Message,), {
  'DESCRIPTOR' : _BRAND,
  '__module__' : 'qwak.administration.account.v1.personalization_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.Brand)
  })
_sym_db.RegisterMessage(Brand)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTPERSONALIZATION._serialized_start=85
  _ACCOUNTPERSONALIZATION._serialized_end=160
  _BRAND._serialized_start=162
  _BRAND._serialized_end=194
# @@protoc_insertion_point(module_scope)
