"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.feature_set_pb2
import qwak.feature_store.features.feature_set_state_pb2
import qwak.feature_store.features.feature_set_types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegisterFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Feature to register"""
    def __init__(
        self,
        *,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> None: ...

global___RegisterFeatureSetRequest = RegisterFeatureSetRequest

class RegisterFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """The newly created feature set"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___RegisterFeatureSetResponse = RegisterFeatureSetResponse

class UpdateFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature set ID to update"""
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Feature set specifications to update"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id", "feature_set_spec", b"feature_set_spec"]) -> None: ...

global___UpdateFeatureSetRequest = UpdateFeatureSetRequest

class UpdateFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """The updated feature set"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___UpdateFeatureSetResponse = UpdateFeatureSetResponse

class GetFeatureSetByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """ID of feature to fetch"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___GetFeatureSetByIdRequest = GetFeatureSetByIdRequest

class GetFeatureSetByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetByIdResponse = GetFeatureSetByIdResponse

class GetFeatureSetByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Name of feature to fetch"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___GetFeatureSetByNameRequest = GetFeatureSetByNameRequest

class GetFeatureSetByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetByNameResponse = GetFeatureSetByNameResponse

class ListFeaturesetVersionsByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset to fetch versions for"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___ListFeaturesetVersionsByNameRequest = ListFeaturesetVersionsByNameRequest

class ListFeaturesetVersionsByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESETS_FIELD_NUMBER: builtins.int
    @property
    def featuresets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_pb2.FeaturesetInfo]:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        featuresets: collections.abc.Iterable[qwak.feature_store.features.feature_set_pb2.FeaturesetInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featuresets", b"featuresets"]) -> None: ...

global___ListFeaturesetVersionsByNameResponse = ListFeaturesetVersionsByNameResponse

class GetEnvToFeatureSetsMappingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetEnvToFeatureSetsMappingRequest = GetEnvToFeatureSetsMappingRequest

class GetEnvToFeatureSetsMappingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvToFeatureSetMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetList: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.feature_store.features.feature_set_pb2.FeatureSetList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENV_TO_FEATURE_SET_MAPPING_FIELD_NUMBER: builtins.int
    @property
    def env_to_feature_set_mapping(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.feature_store.features.feature_set_pb2.FeatureSetList]:
        """Mapping of environment to feature sets"""
    def __init__(
        self,
        *,
        env_to_feature_set_mapping: collections.abc.Mapping[builtins.str, qwak.feature_store.features.feature_set_pb2.FeatureSetList] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env_to_feature_set_mapping", b"env_to_feature_set_mapping"]) -> None: ...

global___GetEnvToFeatureSetsMappingResponse = GetEnvToFeatureSetsMappingResponse

class DeleteFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """ID of feature to delete"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___DeleteFeatureSetRequest = DeleteFeatureSetRequest

class DeleteFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeatureSetResponse = DeleteFeatureSetResponse

class DeleteFeaturesetVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset"""
    featureset_version_number: builtins.int
    """Version number to delete"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        featureset_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "featureset_version_number", b"featureset_version_number"]) -> None: ...

global___DeleteFeaturesetVersionRequest = DeleteFeaturesetVersionRequest

class DeleteFeaturesetVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeaturesetVersionResponse = DeleteFeaturesetVersionResponse

class ListFeatureSetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListFeatureSetsRequest = ListFeatureSetsRequest

class ListFeatureSetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_FAMILIES_FIELD_NUMBER: builtins.int
    @property
    def feature_families(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_pb2.FeatureSet]:
        """List of registered features"""
    def __init__(
        self,
        *,
        feature_families: collections.abc.Iterable[qwak.feature_store.features.feature_set_pb2.FeatureSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_families", b"feature_families"]) -> None: ...

global___ListFeatureSetsResponse = ListFeatureSetsResponse

class RunBatchFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name in order to run now batch job"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___RunBatchFeatureSetRequest = RunBatchFeatureSetRequest

class RunBatchFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RunBatchFeatureSetResponse = RunBatchFeatureSetResponse

class RunParquetBatchFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PARQUET_LOCATION_FIELD_NUMBER: builtins.int
    TIMESTAMP_COLUMN_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name in order to run now batch job"""
    parquet_location: builtins.str
    """The S3 location for the parquet file (can include `*` suffix if parquet is partitioned)"""
    timestamp_column: builtins.str
    """The name of the column in the parquet files that represent the data time dimension"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        parquet_location: builtins.str = ...,
        timestamp_column: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "parquet_location", b"parquet_location", "timestamp_column", b"timestamp_column"]) -> None: ...

global___RunParquetBatchFeatureSetRequest = RunParquetBatchFeatureSetRequest

class RunParquetBatchFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RunParquetBatchFeatureSetResponse = RunParquetBatchFeatureSetResponse

class CreateUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___CreateUploadURLRequest = CreateUploadURLRequest

class CreateUploadURLRequestV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Featureset unique identified"""
    @property
    def transformation(self) -> qwak.feature_store.features.feature_set_types_pb2.Transformation:
        """Transformation belonging to this featureset, used only for its type"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        transformation: qwak.feature_store.features.feature_set_types_pb2.Transformation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "transformation", b"transformation"]) -> None: ...

global___CreateUploadURLRequestV1 = CreateUploadURLRequestV1

class CreateRealTimeFeatureExtractorUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Featureset unique identifier"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___CreateRealTimeFeatureExtractorUploadURLRequest = CreateRealTimeFeatureExtractorUploadURLRequest

class CreateUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the feature code upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___CreateUploadURLResponse = CreateUploadURLResponse

class UpdateFeatureSetStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeatureNamesStateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___StateUpdate: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___StateUpdate | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEATURE_NAMES_STATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def feature_names_state(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___StateUpdate]:
        """Feature Set Names and state"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_names_state: collections.abc.Mapping[builtins.str, global___StateUpdate] | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_names_state", b"feature_names_state"]) -> None: ...

global___UpdateFeatureSetStateRequest = UpdateFeatureSetStateRequest

class StateUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_NAMES_STATE_FIELD_NUMBER: builtins.int
    feature_names_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """The state of the feature"""
    def __init__(
        self,
        *,
        feature_names_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_names_state", b"feature_names_state"]) -> None: ...

global___StateUpdate = StateUpdate

class UpdateFeatureSetStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateFeatureSetStateResponse = UpdateFeatureSetStateResponse

class GetFeatureSetStateByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature Set Name"""
    run_id: builtins.int
    """Running Id. Run-Id with Non-scheduled application will be 0 by default"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        run_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByNameRequest = GetFeatureSetStateByNameRequest

class GetFeatureSetStateByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """Fetched state"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByNameResponse = GetFeatureSetStateByNameResponse

class GetFeatureSetStateByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature Set Name"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___GetFeatureSetStateByIdRequest = GetFeatureSetStateByIdRequest

class GetFeatureSetStateByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetStateByIdResponse = GetFeatureSetStateByIdResponse

class PauseFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___PauseFeaturesetRequest = PauseFeaturesetRequest

class PauseFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PauseFeaturesetResponse = PauseFeaturesetResponse

class ResumeFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___ResumeFeaturesetRequest = ResumeFeaturesetRequest

class ResumeFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ResumeFeaturesetResponse = ResumeFeaturesetResponse

class GetFeaturesetSchedulingStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___GetFeaturesetSchedulingStateRequest = GetFeaturesetSchedulingStateRequest

class GetFeaturesetSchedulingStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: qwak.feature_store.features.feature_set_pb2.FeaturesetSchedulingState.ValueType
    def __init__(
        self,
        *,
        state: qwak.feature_store.features.feature_set_pb2.FeaturesetSchedulingState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___GetFeaturesetSchedulingStateResponse = GetFeaturesetSchedulingStateResponse

class SetActiveFeaturesetVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset"""
    featureset_version_number: builtins.int
    """Version number to set as active"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        featureset_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "featureset_version_number", b"featureset_version_number"]) -> None: ...

global___SetActiveFeaturesetVersionRequest = SetActiveFeaturesetVersionRequest

class SetActiveFeaturesetVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetActiveFeaturesetVersionResponse = SetActiveFeaturesetVersionResponse
