# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/authenticated_user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import details_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_details__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import credentials_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJqwak/administration/authenticated_user/v1/authenticated_user_service.proto\x12)qwak.administration.authenticated_user.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x37qwak/administration/authenticated_user/v1/details.proto\x1a;qwak/administration/authenticated_user/v1/credentials.proto\"\x13\n\x11GetDetailsRequest\"\xae\x01\n\x12GetDetailsResponse\x12\x44\n\x04user\x18\x01 \x01(\x0b\x32\x36.qwak.administration.authenticated_user.v1.UserDetails\x12R\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32=.qwak.administration.authenticated_user.v1.EnvironmentDetails\"\x1e\n\x1cGetEnvironmentDetailsRequest\"s\n\x1dGetEnvironmentDetailsResponse\x12R\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32=.qwak.administration.authenticated_user.v1.EnvironmentDetails\"I\n\x1aGetCloudCredentialsRequest\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"u\n\x1bGetCloudCredentialsResponse\x12V\n\x11\x63loud_credentials\x18\x01 \x01(\x0b\x32;.qwak.administration.authenticated_user.v1.CloudCredentials2\xf3\x03\n\x11\x41uthenticatedUser\x12\x89\x01\n\nGetDetails\x12<.qwak.administration.authenticated_user.v1.GetDetailsRequest\x1a=.qwak.administration.authenticated_user.v1.GetDetailsResponse\x12\xaa\x01\n\x15GetEnvironmentDetails\x12G.qwak.administration.authenticated_user.v1.GetEnvironmentDetailsRequest\x1aH.qwak.administration.authenticated_user.v1.GetEnvironmentDetailsResponse\x12\xa4\x01\n\x13GetCloudCredentials\x12\x45.qwak.administration.authenticated_user.v1.GetCloudCredentialsRequest\x1a\x46.qwak.administration.authenticated_user.v1.GetCloudCredentialsResponseBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')



_GETDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetDetailsRequest']
_GETDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetDetailsResponse']
_GETENVIRONMENTDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetEnvironmentDetailsRequest']
_GETENVIRONMENTDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetEnvironmentDetailsResponse']
_GETCLOUDCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['GetCloudCredentialsRequest']
_GETCLOUDCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['GetCloudCredentialsResponse']
GetDetailsRequest = _reflection.GeneratedProtocolMessageType('GetDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETAILSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetDetailsRequest)
  })
_sym_db.RegisterMessage(GetDetailsRequest)

GetDetailsResponse = _reflection.GeneratedProtocolMessageType('GetDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETAILSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetDetailsResponse)
  })
_sym_db.RegisterMessage(GetDetailsResponse)

GetEnvironmentDetailsRequest = _reflection.GeneratedProtocolMessageType('GetEnvironmentDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTDETAILSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetEnvironmentDetailsRequest)
  })
_sym_db.RegisterMessage(GetEnvironmentDetailsRequest)

GetEnvironmentDetailsResponse = _reflection.GeneratedProtocolMessageType('GetEnvironmentDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTDETAILSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetEnvironmentDetailsResponse)
  })
_sym_db.RegisterMessage(GetEnvironmentDetailsResponse)

GetCloudCredentialsRequest = _reflection.GeneratedProtocolMessageType('GetCloudCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDCREDENTIALSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetCloudCredentialsRequest)
  })
_sym_db.RegisterMessage(GetCloudCredentialsRequest)

GetCloudCredentialsResponse = _reflection.GeneratedProtocolMessageType('GetCloudCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDCREDENTIALSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetCloudCredentialsResponse)
  })
_sym_db.RegisterMessage(GetCloudCredentialsResponse)

_AUTHENTICATEDUSER = DESCRIPTOR.services_by_name['AuthenticatedUser']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _GETDETAILSREQUEST._serialized_start=271
  _GETDETAILSREQUEST._serialized_end=290
  _GETDETAILSRESPONSE._serialized_start=293
  _GETDETAILSRESPONSE._serialized_end=467
  _GETENVIRONMENTDETAILSREQUEST._serialized_start=469
  _GETENVIRONMENTDETAILSREQUEST._serialized_end=499
  _GETENVIRONMENTDETAILSRESPONSE._serialized_start=501
  _GETENVIRONMENTDETAILSRESPONSE._serialized_end=616
  _GETCLOUDCREDENTIALSREQUEST._serialized_start=618
  _GETCLOUDCREDENTIALSREQUEST._serialized_end=691
  _GETCLOUDCREDENTIALSRESPONSE._serialized_start=693
  _GETCLOUDCREDENTIALSRESPONSE._serialized_end=810
  _AUTHENTICATEDUSER._serialized_start=813
  _AUTHENTICATEDUSER._serialized_end=1312
# @@protoc_insertion_point(module_scope)
