# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.offline.serving.v1 import offline_serving_async_service_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2


class FeatureStoreOfflineServingAsyncServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFileUploadUrl = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFileUploadUrl',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.FromString,
                )
        self.GetFeatureValues = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValues',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.FromString,
                )
        self.GetFeatureValuesInRange = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesInRange',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.FromString,
                )
        self.GetFeatureValuesResult = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesResult',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.FromString,
                )


class FeatureStoreOfflineServingAsyncServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFileUploadUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValuesInRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValuesResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureStoreOfflineServingAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFileUploadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUploadUrl,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.SerializeToString,
            ),
            'GetFeatureValues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValues,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.SerializeToString,
            ),
            'GetFeatureValuesInRange': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValuesInRange,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.SerializeToString,
            ),
            'GetFeatureValuesResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValuesResult,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureStoreOfflineServingAsyncService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFileUploadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFileUploadUrl',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValues',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValuesInRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesInRange',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValuesResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesResult',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
