"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.file_versioning.file_versioning_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegisterFileTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_TAG_SPEC_FIELD_NUMBER: builtins.int
    @property
    def file_tag_spec(self) -> qwak.file_versioning.file_versioning_pb2.FileTagSpec: ...
    def __init__(
        self,
        *,
        file_tag_spec: qwak.file_versioning.file_versioning_pb2.FileTagSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file_tag_spec", b"file_tag_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_tag_spec", b"file_tag_spec"]) -> None: ...

global___RegisterFileTagRequest = RegisterFileTagRequest

class RegisterFileTagResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterFileTagResponse = RegisterFileTagResponse

class GetModelFileTagsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id to get file tags for"""
    build_id: builtins.str
    """The build id to get file tags for"""
    @property
    def filter(self) -> qwak.file_versioning.file_versioning_pb2.FileTagFilter:
        """The filter to apply to the file tags"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        filter: qwak.file_versioning.file_versioning_pb2.FileTagFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "filter", b"filter", "model_id", b"model_id"]) -> None: ...

global___GetModelFileTagsRequest = GetModelFileTagsRequest

class GetModelFileTagsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_TAGS_FIELD_NUMBER: builtins.int
    @property
    def file_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.file_versioning.file_versioning_pb2.FileTagSpec]: ...
    def __init__(
        self,
        *,
        file_tags: collections.abc.Iterable[qwak.file_versioning.file_versioning_pb2.FileTagSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_tags", b"file_tags"]) -> None: ...

global___GetModelFileTagsResponse = GetModelFileTagsResponse
