"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.execution.v1.backfill_pb2
import qwak.execution.v1.batch_pb2
import qwak.execution.v1.deletion_pb2
import qwak.execution.v1.streaming_aggregation_pb2
import qwak.execution.v1.streaming_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExecutionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExecutionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExecutionStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXECUTION_STATUS_INVALID: _ExecutionStatus.ValueType  # 0
    EXECUTION_STATUS_QUEUED: _ExecutionStatus.ValueType  # 1
    EXECUTION_STATUS_PENDING: _ExecutionStatus.ValueType  # 2
    EXECUTION_STATUS_RUNNING: _ExecutionStatus.ValueType  # 3
    EXECUTION_STATUS_COMPLETED: _ExecutionStatus.ValueType  # 4
    EXECUTION_STATUS_FAILED: _ExecutionStatus.ValueType  # 5
    EXECUTION_STATUS_CANCELLED: _ExecutionStatus.ValueType  # 6
    EXECUTION_STATUS_SUBMITTED: _ExecutionStatus.ValueType  # 7
    EXECUTION_STATUS_FAILED_SUBMISSION: _ExecutionStatus.ValueType  # 8
    EXECUTION_STATUS_SKIPPED: _ExecutionStatus.ValueType  # 9

class ExecutionStatus(_ExecutionStatus, metaclass=_ExecutionStatusEnumTypeWrapper): ...

EXECUTION_STATUS_INVALID: ExecutionStatus.ValueType  # 0
EXECUTION_STATUS_QUEUED: ExecutionStatus.ValueType  # 1
EXECUTION_STATUS_PENDING: ExecutionStatus.ValueType  # 2
EXECUTION_STATUS_RUNNING: ExecutionStatus.ValueType  # 3
EXECUTION_STATUS_COMPLETED: ExecutionStatus.ValueType  # 4
EXECUTION_STATUS_FAILED: ExecutionStatus.ValueType  # 5
EXECUTION_STATUS_CANCELLED: ExecutionStatus.ValueType  # 6
EXECUTION_STATUS_SUBMITTED: ExecutionStatus.ValueType  # 7
EXECUTION_STATUS_FAILED_SUBMISSION: ExecutionStatus.ValueType  # 8
EXECUTION_STATUS_SKIPPED: ExecutionStatus.ValueType  # 9
global___ExecutionStatus = ExecutionStatus

class ExecutionEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    SUBMITTED_AT_FIELD_NUMBER: builtins.int
    SUBMITTED_BY_FIELD_NUMBER: builtins.int
    TRIGGERED_AT_FIELD_NUMBER: builtins.int
    ENDED_AT_FIELD_NUMBER: builtins.int
    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    BATCH_INGESTION_FIELD_NUMBER: builtins.int
    FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    ONLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    OFFLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    ROW_LEVEL_STREAMING_AGGREGATION_INGESTION_FIELD_NUMBER: builtins.int
    COMPACTION_STREAMING_AGGREGATION_INGESTION_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_BACKFILL_INGESTION_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    execution_id: builtins.str
    execution_status: global___ExecutionStatus.ValueType
    @property
    def submitted_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def submitted_by(self) -> global___InvokerDetails: ...
    @property
    def triggered_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def ended_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec:
        """Batch Backfill"""
    @property
    def batch_ingestion(self) -> qwak.execution.v1.batch_pb2.BatchIngestion:
        """"Regular" batch ingestion"""
    @property
    def featureset_deletion(self) -> qwak.execution.v1.deletion_pb2.FeaturesetDeletion:
        """Featureset deletion"""
    @property
    def online_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion:
        """Online Streaming Ingestion"""
    @property
    def offline_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion:
        """Offline Streaming Ingestion"""
    @property
    def row_level_streaming_aggregation_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion:
        """Streaming Aggregation RowLevel"""
    @property
    def compaction_streaming_aggregation_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion:
        """Streaming Aggregation Compaction"""
    @property
    def streaming_aggregation_backfill_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion:
        """Streaming Aggregation Backfill"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        execution_id: builtins.str = ...,
        execution_status: global___ExecutionStatus.ValueType = ...,
        submitted_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        submitted_by: global___InvokerDetails | None = ...,
        triggered_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ended_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
        batch_ingestion: qwak.execution.v1.batch_pb2.BatchIngestion | None = ...,
        featureset_deletion: qwak.execution.v1.deletion_pb2.FeaturesetDeletion | None = ...,
        online_streaming_ingestion: qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion | None = ...,
        offline_streaming_ingestion: qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion | None = ...,
        row_level_streaming_aggregation_ingestion: qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion | None = ...,
        compaction_streaming_aggregation_ingestion: qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion | None = ...,
        streaming_aggregation_backfill_ingestion: qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "batch_ingestion", b"batch_ingestion", "compaction_streaming_aggregation_ingestion", b"compaction_streaming_aggregation_ingestion", "ended_at", b"ended_at", "execution_type", b"execution_type", "featureset_deletion", b"featureset_deletion", "offline_streaming_ingestion", b"offline_streaming_ingestion", "online_streaming_ingestion", b"online_streaming_ingestion", "row_level_streaming_aggregation_ingestion", b"row_level_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion", b"streaming_aggregation_backfill_ingestion", "submitted_at", b"submitted_at", "submitted_by", b"submitted_by", "triggered_at", b"triggered_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "batch_ingestion", b"batch_ingestion", "compaction_streaming_aggregation_ingestion", b"compaction_streaming_aggregation_ingestion", "ended_at", b"ended_at", "execution_id", b"execution_id", "execution_status", b"execution_status", "execution_type", b"execution_type", "featureset_deletion", b"featureset_deletion", "featureset_id", b"featureset_id", "offline_streaming_ingestion", b"offline_streaming_ingestion", "online_streaming_ingestion", b"online_streaming_ingestion", "row_level_streaming_aggregation_ingestion", b"row_level_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion", b"streaming_aggregation_backfill_ingestion", "submitted_at", b"submitted_at", "submitted_by", b"submitted_by", "triggered_at", b"triggered_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["execution_type", b"execution_type"]) -> typing_extensions.Literal["backfill_spec", "batch_ingestion", "featureset_deletion", "online_streaming_ingestion", "offline_streaming_ingestion", "row_level_streaming_aggregation_ingestion", "compaction_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion"] | None: ...

global___ExecutionEntry = ExecutionEntry

class InvokerDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_INVOKER_FIELD_NUMBER: builtins.int
    INTERNAL_INVOKER_FIELD_NUMBER: builtins.int
    @property
    def external_invoker(self) -> global___ExternalInvoker:
        """External Invoker - a user hit RunNow etc."""
    @property
    def internal_invoker(self) -> global___InternalInvoker:
        """Internal Invoker - a Scheduled run"""
    def __init__(
        self,
        *,
        external_invoker: global___ExternalInvoker | None = ...,
        internal_invoker: global___InternalInvoker | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["external_invoker", b"external_invoker", "internal_invoker", b"internal_invoker", "invoker_type", b"invoker_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_invoker", b"external_invoker", "internal_invoker", b"internal_invoker", "invoker_type", b"invoker_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["invoker_type", b"invoker_type"]) -> typing_extensions.Literal["external_invoker", "internal_invoker"] | None: ...

global___InvokerDetails = InvokerDetails

class ExternalInvoker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVOKER_EMAIL_FIELD_NUMBER: builtins.int
    invoker_email: builtins.str
    def __init__(
        self,
        *,
        invoker_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invoker_email", b"invoker_email"]) -> None: ...

global___ExternalInvoker = ExternalInvoker

class InternalInvoker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InternalInvoker = InternalInvoker
