# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/auto_scaling/v1/auto_scaling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'qwak/auto_scaling/v1/auto_scaling.proto\x12\x14qwak.auto_scaling.v1\"\xaf\x01\n\x11\x41utoScalingConfig\x12\x19\n\x11min_replica_count\x18\x01 \x01(\x05\x12\x19\n\x11max_replica_count\x18\x02 \x01(\x05\x12\x18\n\x10polling_interval\x18\x03 \x01(\x05\x12\x18\n\x10\x63ool_down_period\x18\x04 \x01(\x05\x12\x30\n\x08triggers\x18\x05 \x01(\x0b\x32\x1e.qwak.auto_scaling.v1.Triggers\";\n\x08Triggers\x12/\n\x08triggers\x18\x01 \x03(\x0b\x32\x1d.qwak.auto_scaling.v1.Trigger\"`\n\x07Trigger\x12\x45\n\x12prometheus_trigger\x18\x01 \x01(\x0b\x32\'.qwak.auto_scaling.v1.PrometheusTriggerH\x00\x42\x0e\n\x0ctrigger_type\"[\n\x11PrometheusTrigger\x12\x33\n\nquery_spec\x18\x01 \x01(\x0b\x32\x1f.qwak.auto_scaling.v1.QuerySpec\x12\x11\n\tthreshold\x18\x02 \x01(\x05\"\xac\x01\n\tQuerySpec\x12\x35\n\x0bmetric_type\x18\x01 \x01(\x0e\x32 .qwak.auto_scaling.v1.MetricType\x12?\n\x10\x61ggregation_type\x18\x02 \x01(\x0e\x32%.qwak.auto_scaling.v1.AggregationType\x12\x13\n\x0btime_period\x18\x03 \x01(\x05\x12\x12\n\nerror_code\x18\x04 \x01(\t*\xba\x01\n\nMetricType\x12\x19\n\x15METRIC_TYPE_NOT_VALID\x10\x00\x12\x13\n\x0fMETRIC_TYPE_CPU\x10\x01\x12\x16\n\x12METRIC_TYPE_MEMORY\x10\x02\x12\x17\n\x13METRIC_TYPE_LATENCY\x10\x03\x12\x13\n\x0fMETRIC_TYPE_GPU\x10\x04\x12\x1a\n\x16METRIC_TYPE_ERROR_RATE\x10\x05\x12\x1a\n\x16METRIC_TYPE_THROUGHPUT\x10\x06*\x85\x02\n\x0f\x41ggregationType\x12\x1e\n\x1a\x41GGREGATION_TYPE_NOT_VALID\x10\x00\x12\x18\n\x14\x41GGREGATION_TYPE_MIN\x10\x01\x12\x18\n\x14\x41GGREGATION_TYPE_MAX\x10\x02\x12\x1c\n\x18\x41GGREGATION_TYPE_AVERAGE\x10\x03\x12\x18\n\x14\x41GGREGATION_TYPE_SUM\x10\x04\x12\x18\n\x14\x41GGREGATION_TYPE_P50\x10\x05\x12\x18\n\x14\x41GGREGATION_TYPE_P90\x10\x06\x12\x18\n\x14\x41GGREGATION_TYPE_P95\x10\x07\x12\x18\n\x14\x41GGREGATION_TYPE_P99\x10\x08\x42K\n%com.qwak.ai.management.deployment.apiP\x01Z qwak/auto_scaling/v1;autoscalingb\x06proto3')

_METRICTYPE = DESCRIPTOR.enum_types_by_name['MetricType']
MetricType = enum_type_wrapper.EnumTypeWrapper(_METRICTYPE)
_AGGREGATIONTYPE = DESCRIPTOR.enum_types_by_name['AggregationType']
AggregationType = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONTYPE)
METRIC_TYPE_NOT_VALID = 0
METRIC_TYPE_CPU = 1
METRIC_TYPE_MEMORY = 2
METRIC_TYPE_LATENCY = 3
METRIC_TYPE_GPU = 4
METRIC_TYPE_ERROR_RATE = 5
METRIC_TYPE_THROUGHPUT = 6
AGGREGATION_TYPE_NOT_VALID = 0
AGGREGATION_TYPE_MIN = 1
AGGREGATION_TYPE_MAX = 2
AGGREGATION_TYPE_AVERAGE = 3
AGGREGATION_TYPE_SUM = 4
AGGREGATION_TYPE_P50 = 5
AGGREGATION_TYPE_P90 = 6
AGGREGATION_TYPE_P95 = 7
AGGREGATION_TYPE_P99 = 8


_AUTOSCALINGCONFIG = DESCRIPTOR.message_types_by_name['AutoScalingConfig']
_TRIGGERS = DESCRIPTOR.message_types_by_name['Triggers']
_TRIGGER = DESCRIPTOR.message_types_by_name['Trigger']
_PROMETHEUSTRIGGER = DESCRIPTOR.message_types_by_name['PrometheusTrigger']
_QUERYSPEC = DESCRIPTOR.message_types_by_name['QuerySpec']
AutoScalingConfig = _reflection.GeneratedProtocolMessageType('AutoScalingConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSCALINGCONFIG,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.AutoScalingConfig)
  })
_sym_db.RegisterMessage(AutoScalingConfig)

Triggers = _reflection.GeneratedProtocolMessageType('Triggers', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERS,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.Triggers)
  })
_sym_db.RegisterMessage(Triggers)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

PrometheusTrigger = _reflection.GeneratedProtocolMessageType('PrometheusTrigger', (_message.Message,), {
  'DESCRIPTOR' : _PROMETHEUSTRIGGER,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.PrometheusTrigger)
  })
_sym_db.RegisterMessage(PrometheusTrigger)

QuerySpec = _reflection.GeneratedProtocolMessageType('QuerySpec', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPEC,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.QuerySpec)
  })
_sym_db.RegisterMessage(QuerySpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z qwak/auto_scaling/v1;autoscaling'
  _METRICTYPE._serialized_start=671
  _METRICTYPE._serialized_end=857
  _AGGREGATIONTYPE._serialized_start=860
  _AGGREGATIONTYPE._serialized_end=1121
  _AUTOSCALINGCONFIG._serialized_start=66
  _AUTOSCALINGCONFIG._serialized_end=241
  _TRIGGERS._serialized_start=243
  _TRIGGERS._serialized_end=302
  _TRIGGER._serialized_start=304
  _TRIGGER._serialized_end=400
  _PROMETHEUSTRIGGER._serialized_start=402
  _PROMETHEUSTRIGGER._serialized_end=493
  _QUERYSPEC._serialized_start=496
  _QUERYSPEC._serialized_end=668
# @@protoc_insertion_point(module_scope)
