# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.kube_deployment_captain import batch_job_pb2 as qwak_dot_kube__deployment__captain_dot_batch__job__pb2
from _qwak_proto.qwak.kube_deployment_captain import kube_deployment_captain_service_pb2 as qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2


class KubeDeploymentCaptainStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.KubeDeployModel = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/KubeDeployModel',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelResponse.FromString,
                )
        self.KubeUndeployModel = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/KubeUndeployModel',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelResponse.FromString,
                )
        self.ApplyModelTrafficMapping = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyModelTrafficMapping',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingResponse.FromString,
                )
        self.GetKubeModelDeploymentStatus = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/GetKubeModelDeploymentStatus',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusResponse.FromString,
                )
        self.RevertFailedKubeDeployment = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/RevertFailedKubeDeployment',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentResponse.FromString,
                )
        self.UpdateKubeDeploymentRuntimeSettings = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UpdateKubeDeploymentRuntimeSettings',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsResponse.FromString,
                )
        self.ApplyModelsAlerts = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyModelsAlerts',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsResponse.FromString,
                )
        self.ApplyNotificationChannel = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyNotificationChannel',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationsChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationChannelResponse.FromString,
                )
        self.DeleteNotificationChannel = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteNotificationChannel',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelResponse.FromString,
                )
        self.DeployFeatureSetProcessor = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployFeatureSetProcessor',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
                )
        self.DeployStreamingFeatureSetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingFeatureSetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
                )
        self.DeployStreamingOnlineFeatureSetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingOnlineFeatureSetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
                )
        self.DeployStreamingOfflineFeatureSetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingOfflineFeatureSetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
                )
        self.DeployBatchFeatureSetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployBatchFeatureSetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.BatchFeatureSetV1DeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
                )
        self.UndeployFeatureSet = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployFeatureSet',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetResponse.FromString,
                )
        self.UndeployBatchFeatureset = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployBatchFeatureset',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetResponse.FromString,
                )
        self.ListInferenceJobFiles = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ListInferenceJobFiles',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesResponse.FromString,
                )
        self.CreateInferenceTaskExecution = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CreateInferenceTaskExecution',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorResponse.FromString,
                )
        self.CleanInferenceTasksExecutors = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CleanInferenceTasksExecutors',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsResponse.FromString,
                )
        self.CleanInferenceTaskExecutor = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CleanInferenceTaskExecutor',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorResponse.FromString,
                )
        self.StartInferenceJobWarmup = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/StartInferenceJobWarmup',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupResponse.FromString,
                )
        self.CancelInferenceJobWarmup = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CancelInferenceJobWarmup',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupResponse.FromString,
                )
        self.PrepareInferenceJob = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/PrepareInferenceJob',
                request_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobResponse.FromString,
                )
        self.CreateOrReplaceFeatureSetAlert = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CreateOrReplaceFeatureSetAlert',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetAlertRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetFailureResponse.FromString,
                )
        self.DeleteFeatureSetAlert = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteFeatureSetAlert',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertResponse.FromString,
                )
        self.DeployStreamingAggregationBackfill = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationBackfill',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillResponse.FromString,
                )
        self.DeployStreamingAggregationCompaction = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationCompaction',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionResponse.FromString,
                )
        self.DeployStreamingAggregationRowLevel = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationRowLevel',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelResponse.FromString,
                )
        self.DeleteBatchFeaturesetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteBatchFeaturesetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Request.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Response.FromString,
                )
        self.DeleteStreamingFeatureSetV1 = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteStreamingFeatureSetV1',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Request.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Response.FromString,
                )
        self.DeleteStreamingAggregationFeatureSet = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteStreamingAggregationFeatureSet',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetResponse.FromString,
                )
        self.DeployBatchBackfill = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployBatchBackfill',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillResponse.FromString,
                )
        self.UndeployBatchBackfill = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployBatchBackfill',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillResponse.FromString,
                )
        self.RevertModelDeployment = channel.unary_unary(
                '/qwak.kube.deployment.captain.KubeDeploymentCaptain/RevertModelDeployment',
                request_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentResponse.FromString,
                )


class KubeDeploymentCaptainServicer(object):
    """Missing associated documentation comment in .proto file."""

    def KubeDeployModel(self, request, context):
        """Deploy a model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KubeUndeployModel(self, request, context):
        """Undeploy a model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyModelTrafficMapping(self, request, context):
        """Change mappings to existing deployments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKubeModelDeploymentStatus(self, request, context):
        """Get the status of deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevertFailedKubeDeployment(self, request, context):
        """Revert deployment to previous state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateKubeDeploymentRuntimeSettings(self, request, context):
        """Set the setting on runtime
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyModelsAlerts(self, request, context):
        """Update Alerts for model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyNotificationChannel(self, request, context):
        """Add and Update Channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotificationChannel(self, request, context):
        """Delete channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployFeatureSetProcessor(self, request, context):
        """Deploy Features Set Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingFeatureSetV1(self, request, context):
        """Deploy Streaming Features Set V1
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingOnlineFeatureSetV1(self, request, context):
        """Deploy Online Streaming Features Set V1
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingOfflineFeatureSetV1(self, request, context):
        """Deploy Offline Streaming Features Set V1
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployBatchFeatureSetV1(self, request, context):
        """Deploy Batch Features Set V1
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployFeatureSet(self, request, context):
        """Undeploy Features Set Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployBatchFeatureset(self, request, context):
        """Undeploy Features Set Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInferenceJobFiles(self, request, context):
        """List files on folder
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInferenceTaskExecution(self, request, context):
        """Create Kubernetes job for a batch task
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CleanInferenceTasksExecutors(self, request, context):
        """Clean All Inference jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CleanInferenceTaskExecutor(self, request, context):
        """Clean A single Inference task
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartInferenceJobWarmup(self, request, context):
        """Start a warmup job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelInferenceJobWarmup(self, request, context):
        """Cancel warmup job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareInferenceJob(self, request, context):
        """Prepare environment for a job run
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrReplaceFeatureSetAlert(self, request, context):
        """Create or replace FeatureSet failure alert
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSetAlert(self, request, context):
        """Delete FeatureSet alert
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingAggregationBackfill(self, request, context):
        """Create Streaming Aggregation backfill
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingAggregationCompaction(self, request, context):
        """Create Streaming Aggregation compaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployStreamingAggregationRowLevel(self, request, context):
        """Create Streaming Aggregation row level
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchFeaturesetV1(self, request, context):
        """triggers a deletion of a BatchFeatureSetV1
        this includes the data (offline+online) - it does not include un-deploying existing ingestion jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStreamingFeatureSetV1(self, request, context):
        """triggers a deletion of a StreamingFeatureSetV1
        this includes the data (offline+online) - it does not include un-deploying existing ingestion jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStreamingAggregationFeatureSet(self, request, context):
        """triggers a deletion of a StreamingAggregationFeatureSet
        this includes the data (offline+online) - it does not include un-deploying existing ingestion jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployBatchBackfill(self, request, context):
        """triggers a batch backfill
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployBatchBackfill(self, request, context):
        """undeploys a batck backfill, if exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevertModelDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KubeDeploymentCaptainServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'KubeDeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.KubeDeployModel,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelResponse.SerializeToString,
            ),
            'KubeUndeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.KubeUndeployModel,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelResponse.SerializeToString,
            ),
            'ApplyModelTrafficMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyModelTrafficMapping,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingResponse.SerializeToString,
            ),
            'GetKubeModelDeploymentStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKubeModelDeploymentStatus,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusResponse.SerializeToString,
            ),
            'RevertFailedKubeDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.RevertFailedKubeDeployment,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentResponse.SerializeToString,
            ),
            'UpdateKubeDeploymentRuntimeSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateKubeDeploymentRuntimeSettings,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsResponse.SerializeToString,
            ),
            'ApplyModelsAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyModelsAlerts,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsResponse.SerializeToString,
            ),
            'ApplyNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyNotificationChannel,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationsChannelRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationChannelResponse.SerializeToString,
            ),
            'DeleteNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotificationChannel,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelResponse.SerializeToString,
            ),
            'DeployFeatureSetProcessor': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployFeatureSetProcessor,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.SerializeToString,
            ),
            'DeployStreamingFeatureSetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingFeatureSetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.SerializeToString,
            ),
            'DeployStreamingOnlineFeatureSetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingOnlineFeatureSetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.SerializeToString,
            ),
            'DeployStreamingOfflineFeatureSetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingOfflineFeatureSetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.SerializeToString,
            ),
            'DeployBatchFeatureSetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployBatchFeatureSetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.BatchFeatureSetV1DeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.SerializeToString,
            ),
            'UndeployFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployFeatureSet,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetResponse.SerializeToString,
            ),
            'UndeployBatchFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployBatchFeatureset,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetResponse.SerializeToString,
            ),
            'ListInferenceJobFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInferenceJobFiles,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesResponse.SerializeToString,
            ),
            'CreateInferenceTaskExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInferenceTaskExecution,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorResponse.SerializeToString,
            ),
            'CleanInferenceTasksExecutors': grpc.unary_unary_rpc_method_handler(
                    servicer.CleanInferenceTasksExecutors,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsResponse.SerializeToString,
            ),
            'CleanInferenceTaskExecutor': grpc.unary_unary_rpc_method_handler(
                    servicer.CleanInferenceTaskExecutor,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorResponse.SerializeToString,
            ),
            'StartInferenceJobWarmup': grpc.unary_unary_rpc_method_handler(
                    servicer.StartInferenceJobWarmup,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupResponse.SerializeToString,
            ),
            'CancelInferenceJobWarmup': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelInferenceJobWarmup,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupResponse.SerializeToString,
            ),
            'PrepareInferenceJob': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareInferenceJob,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobResponse.SerializeToString,
            ),
            'CreateOrReplaceFeatureSetAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrReplaceFeatureSetAlert,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetAlertRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetFailureResponse.SerializeToString,
            ),
            'DeleteFeatureSetAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSetAlert,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertResponse.SerializeToString,
            ),
            'DeployStreamingAggregationBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingAggregationBackfill,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillResponse.SerializeToString,
            ),
            'DeployStreamingAggregationCompaction': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingAggregationCompaction,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionResponse.SerializeToString,
            ),
            'DeployStreamingAggregationRowLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployStreamingAggregationRowLevel,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelResponse.SerializeToString,
            ),
            'DeleteBatchFeaturesetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchFeaturesetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Request.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Response.SerializeToString,
            ),
            'DeleteStreamingFeatureSetV1': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStreamingFeatureSetV1,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Request.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Response.SerializeToString,
            ),
            'DeleteStreamingAggregationFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStreamingAggregationFeatureSet,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetResponse.SerializeToString,
            ),
            'DeployBatchBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployBatchBackfill,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillResponse.SerializeToString,
            ),
            'UndeployBatchBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployBatchBackfill,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillResponse.SerializeToString,
            ),
            'RevertModelDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.RevertModelDeployment,
                    request_deserializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentRequest.FromString,
                    response_serializer=qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.kube.deployment.captain.KubeDeploymentCaptain', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KubeDeploymentCaptain(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def KubeDeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/KubeDeployModel',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeDeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KubeUndeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/KubeUndeployModel',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.KubeUndeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyModelTrafficMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyModelTrafficMapping',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelTrafficMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKubeModelDeploymentStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/GetKubeModelDeploymentStatus',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.GetKubeModelDeploymentStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevertFailedKubeDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/RevertFailedKubeDeployment',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertFailedKubeDeploymentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateKubeDeploymentRuntimeSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UpdateKubeDeploymentRuntimeSettings',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UpdateKubeDeploymentRuntimeSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyModelsAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyModelsAlerts',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyModelsAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ApplyNotificationChannel',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationsChannelRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.ApplyNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteNotificationChannel',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployFeatureSetProcessor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployFeatureSetProcessor',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingFeatureSetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingFeatureSetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingOnlineFeatureSetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingOnlineFeatureSetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingOfflineFeatureSetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingOfflineFeatureSetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.StreamingFeatureSetV1DeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployBatchFeatureSetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployBatchFeatureSetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.BatchFeatureSetV1DeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployFeatureSet',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployBatchFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployBatchFeatureset',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInferenceJobFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/ListInferenceJobFiles',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.ListInferenceJobFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInferenceTaskExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CreateInferenceTaskExecution',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CreateInferenceTaskExecutorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CleanInferenceTasksExecutors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CleanInferenceTasksExecutors',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTasksExecutorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CleanInferenceTaskExecutor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CleanInferenceTaskExecutor',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CleanInferenceTaskExecutorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartInferenceJobWarmup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/StartInferenceJobWarmup',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.StartInferenceJobWarmupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelInferenceJobWarmup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CancelInferenceJobWarmup',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.CancelInferenceJobWarmupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PrepareInferenceJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/PrepareInferenceJob',
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_batch__job__pb2.PrepareInferenceJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrReplaceFeatureSetAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/CreateOrReplaceFeatureSetAlert',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetAlertRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.CreateOrReplaceFeatureSetFailureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSetAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteFeatureSetAlert',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteFeatureSetAlertResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingAggregationBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationBackfill',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingAggregationCompaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationCompaction',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationCompactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployStreamingAggregationRowLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployStreamingAggregationRowLevel',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployStreamingAggregationRowLevelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBatchFeaturesetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteBatchFeaturesetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Request.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteBatchFeatureSetV1Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStreamingFeatureSetV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteStreamingFeatureSetV1',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Request.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingFeatureSetV1Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStreamingAggregationFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeleteStreamingAggregationFeatureSet',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeleteStreamingAggregationFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployBatchBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/DeployBatchBackfill',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.DeployBatchBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployBatchBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/UndeployBatchBackfill',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.UndeployBatchBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevertModelDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.kube.deployment.captain.KubeDeploymentCaptain/RevertModelDeployment',
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentRequest.SerializeToString,
            qwak_dot_kube__deployment__captain_dot_kube__deployment__captain__service__pb2.RevertModelDeploymentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
